[or-cvs] rendmid says it drops but actually sends nack

Roger Dingledine arma at seul.org
Mon Apr 26 23:02:22 UTC 2004


Update of /home/or/cvsroot/src/or
In directory moria.mit.edu:/home2/arma/work/onion/cvs/src/or

Modified Files:
	rendmid.c 
Log Message:
rendmid says it drops but actually sends nack
fix log messages


Index: rendmid.c
===================================================================
RCS file: /home/or/cvsroot/src/or/rendmid.c,v
retrieving revision 1.18
retrieving revision 1.19
diff -u -d -r1.18 -r1.19
--- rendmid.c	12 Apr 2004 23:33:47 -0000	1.18
+++ rendmid.c	26 Apr 2004 23:02:20 -0000	1.19
@@ -123,7 +123,7 @@
   if (request_len < (DIGEST_LEN+(MAX_NICKNAME_LEN+1)+REND_COOKIE_LEN+
                      DH_KEY_LEN+CIPHER_KEY_LEN+PKCS1_OAEP_PADDING_OVERHEAD)) {
     log_fn(LOG_WARN,
-           "Impossibly short INTRODUCE1 cell on circuit %d; dropping.",
+           "Impossibly short INTRODUCE1 cell on circuit %d; responding with nack.",
            circ->p_circ_id);
     goto err;
   }
@@ -132,13 +132,12 @@
     goto err;
   }
 
-
   /* The first 20 bytes are all we look at: they have a hash of Bob's PK. */
   intro_circ = circuit_get_next_by_pk_and_purpose(
                              NULL, request, CIRCUIT_PURPOSE_INTRO_POINT);
   if (!intro_circ) {
     log_fn(LOG_WARN,
-           "No intro circ found for INTRODUCE1 cell (%s) from circuit %d; dropping",
+           "No intro circ found for INTRODUCE1 cell (%s) from circuit %d; responding with nack",
            serviceid, circ->p_circ_id);
     goto err;
   }
@@ -164,7 +163,7 @@
 
   return 0;
  err:
   /* Send the client an ACK */
   nak_body[0] = 1;
   if (connection_edge_send_command(NULL,circ,RELAY_COMMAND_INTRODUCE_ACK,
                                    nak_body, 1, NULL)) {
@@ -164,7 +163,7 @@
   return 0;
  err:
-  /* Send the client an ACK */
+  /* Send the client an NACK */
   nak_body[0] = 1;
   if (connection_edge_send_command(NULL,circ,RELAY_COMMAND_INTRODUCE_ACK,



More information about the tor-commits mailing list